@@ -1,9 +1,13 @@
-from hostz.base_shell import BaseShell
+from hostz._base_shell import BaseShell
 
 
 class _Sed(BaseShell):
-    def sed_delete(self, match_str, file_path):
-        cmd = f"sed -i '/{match_str}/d' {file_path}"
+    def sed_delete(self, match_str, file_path, after_line_cnt: int = None):
+        match_str = match_str.replace('/', '\/')
+        if after_line_cnt is None:
+            cmd = f"sed -i '/{match_str}/d' {file_path}"
+        else:
+            cmd = f"sed -i '/{match_str}/,+{after_line_cnt}d' {file_path}"
         return self.execute(cmd)
 
     def sed_add(self, match_str, new_str, file_path):
@@ -17,4 +21,3 @@ class _Sed(BaseShell):
     def sed_replace(self, match_str, new_str, file_path):
         cmd = f"sed -i 's%{match_str}%{new_str}%g' {file_path}"
         return self.execute(cmd)
-
